Dojo Slider Widget Demo

# Slider

Also try using the arrow keys, buttons, or clicking on the progress bar to move the slider.

## Horizontal Slider Example

initial value=10, min=0, max=100, pageIncrement=100, onChange event triggers input box value change immediately

1. lowest
2. normal
3. highest

Slider1 Value:

## Vertical Slider Example

initial value=10, min=0, max=100, onChange event triggers input box value change when you mouse up or tab away

1. 0
2. 100

Slider2 Value:

## Fancy HTML labels (no slide animation):

1. small
2. medium
3. large

## Standalone ruler example:

2. 1
3. 2

## Horizontal, with buttons, disabled (to show styling):

1. lowest
2. normal
3. highest

## Fractional Slider Example

initial value=0.28, min=0, max=2, onChange event triggers input box value change when you mouse up or tab away
Fractional Slider Value: